@@ -1,34 +1,35 @@
 package Dancer::Plugin::reCAPTCHA;
 # ABSTRACT: Easily integrate reCAPTCHA into your Dancer applications
 {
-    $Dancer::Plugin::reCAPTCHA::VERSION = '0.10';
+    $Dancer::Plugin::reCAPTCHA::VERSION = '0.2';
 }
 
 
 use Dancer ':syntax';
 use Dancer::Plugin;
-use Captcha::reCAPTCHA::V2;
+use Captcha::reCAPTCHA;
 
-my $rc = Captcha::reCAPTCHA::V2->new;
+my $conf = plugin_setting();
+my $rc   = Captcha::reCAPTCHA->new;
 
 
 register recaptcha_display => sub {
-    my $conf = plugin_setting();
-    my %options = map { $_ => $conf->$_ if defined $conf->$_ } (qw[ theme type size ]);
-    return $rc->html(
+    return $rc->get_html( 
         $conf->{ public_key },
-        { %options }
+        undef,
+        $conf->{ use_ssl },
+        undef,
     );
 };
 
 
 register recaptcha_check => sub {
-    my ( $response ) = @_;
-    my $conf = plugin_setting();
-    return $rc->verify(
+    my ( $challenge, $response ) = @_;
+    return $rc->check_answer(
         $conf->{ private_key },
-        $response,
         request->remote_address,
+        $challenge,
+        $response,
     );
 };
 
@@ -40,31 +41,19 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 Dancer::Plugin::reCAPTCHA - Easily integrate reCAPTCHA into your Dancer applications
 
 =head1 VERSION
 
-version 0.10
+version 0.2
 
 =head1 SYNOPSIS
 
-    # In your config.yml 
-    plugins: 
-        reCAPTCHA: 
-            public_key: "public key goes here" 
-            private_key: "private key goes here" 
-            theme: "dark"
-            type: "image"
-            size: "normal"
-
-    # In your Dancer app...
     use Dancer::Plugin::reCAPTCHA;
 
-    # In your form display route...
+    # In your form display....
     return template 'accounts/create', { 
         recaptcha => recaptcha_display(),
     };
@@ -73,13 +62,17 @@ version 0.10
     [% recaptcha %]
 
     # In your validation code....
+    my $challenge = param( 'recaptcha_challenge_field' );
     my $response  = param( 'recaptcha_response_field' );
-    my $result    = recaptcha_check( $response );
-    die "User didn't match the CAPTCHA" unless $result->{ success };
+    my $result    = recaptcha_check(
+        $challenge, 
+        $response,
+    );
+    die "User didn't match the CAPTCHA" unless $result->{ is_valid };
 
 =head1 METHODS
 
-=head2 recaptcha_display()
+=head2 recaptcha_display( )
 
 Generates the HTML needed to display the CAPTCHA.  This HTML is returned as
 a scalar value, and can easily be plugged into the template system of your 
@@ -95,40 +88,36 @@ Using Template Toolkit as an example, this might look like:
     # In your accounts/create template
     [% recaptcha %]
 
-=head2 recaptcha_check()
+=head2 recaptcha_check( $$ )
 
 Verify that the value the user entered matches what's in the CAPTCHA.  This
-methods takes an argument that is the response string.
-These are returned to your Dancer application as the parameter
-F< g-recaptcha-response >.
+methods takes two arguments: the challenge string and the response string.  
+These are returned to your Dancer application as two parameters: 
+F< recaptcha_challenge_field > and F< recaptcha_response_field >.
 
 For example:
 
-    my $response  = param( 'g-recaptcha-response' );
-    my $result    = recaptcha_check( $response );
-    die "User didn't match the CAPTCHA" unless $result->{ success };
+    my $challenge = param( 'recaptcha_challenge_field' );
+    my $response  = param( 'recaptcha_response_field' );
+    my $result    = recaptcha_check(
+        $challenge, 
+        $response,
+    );
+    die "User didn't match the CAPTCHA" unless $result->{ is_valid };
 
-See L<Captcha::reCAPTCHA::V2> for a description of the result hash.
+See L<Captcha::reCAPTCHA> for a description of the result hash.
 
 =head2 TODO
 
 Add a real test suite.
 
-=head1 CREDITS
-
-The following people have contributes to C<Dancer::Plugin::reCAPTCHA> in some 
-way, either through bug reports, code, suggestions, or moral support:
-
-Mohammad S Anwar
-Shawn Sorichetti
-
 =head1 SEE ALSO
 
 =over 4
 
 =item *
 
-L<Captcha::reCAPTCHA::V2>
+L<Captcha::reCAPTCHA>
 
 =item *
 
@@ -146,7 +135,7 @@ Jason A. Crome <cromedome@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Jason A. Crome.
+This software is copyright (c) 2013 by Jason A. Crome.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
